==> haskell-hjsonpointer-1.5.0-58-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hjsonpointer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hjsonpointer
version:              1.5.0
visibility:           public
id:                   hjsonpointer-1.5.0-8Zc5F3rSqBOHHtDdb2B3RQ
key:                  hjsonpointer-1.5.0-8Zc5F3rSqBOHHtDdb2B3RQ
license:              MIT
maintainer:           ian@housejeffries.com
author:               Ian Grant Jeffries
homepage:             https://github.com/seagreen/hjsonpointer
synopsis:             JSON Pointer library
category:             Data
abi:                  5c6a30ee0784884eb99e886dc5990fb3
exposed:              True
exposed-modules:      JSONPointer
import-dirs:          /usr/lib/ghc-8.8.1/site-local/hjsonpointer-1.5.0
library-dirs:         /usr/lib/ghc-8.8.1/site-local/hjsonpointer-1.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.1/hjsonpointer-1.5.0
hs-libraries:         HShjsonpointer-1.5.0-8Zc5F3rSqBOHHtDdb2B3RQ
depends:
    aeson-1.4.6.0-E2BkI4IZQTS95PTQn3BtDE base-4.13.0.0
    hashable-1.2.7.0-Jxai6kzZTBkIQjxJHBmP5T text-1.2.4.0
    unordered-containers-0.2.10.0-BOyMat0aeilHaccjX66VbF
    vector-0.12.0.3-5jznHM9LsC6GoMm8iesU7Q

haddock-interfaces:
    /usr/share/doc/haskell-hjsonpointer/html/hjsonpointer.haddock

haddock-html:         /usr/share/doc/haskell-hjsonpointer/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hjsonpointer-1.5.0-67-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hjsonpointer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hjsonpointer
version:              1.5.0
visibility:           public
id:                   hjsonpointer-1.5.0-1xMQZO0r75d9QIpDJJAOHm
key:                  hjsonpointer-1.5.0-1xMQZO0r75d9QIpDJJAOHm
license:              MIT
maintainer:           ian@housejeffries.com
author:               Ian Grant Jeffries
homepage:             https://github.com/seagreen/hjsonpointer
synopsis:             JSON Pointer library
category:             Data
abi:                  bc5e8566592f2a465e48be8cb7546e5f
exposed:              True
exposed-modules:      JSONPointer
import-dirs:          /usr/lib/ghc-8.8.1/site-local/hjsonpointer-1.5.0
library-dirs:         /usr/lib/ghc-8.8.1/site-local/hjsonpointer-1.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.1/hjsonpointer-1.5.0
hs-libraries:         HShjsonpointer-1.5.0-1xMQZO0r75d9QIpDJJAOHm
depends:
    aeson-1.4.6.0-14aMj661H7U58XQ3xLLXvh base-4.13.0.0
    hashable-1.2.7.0-Jxai6kzZTBkIQjxJHBmP5T text-1.2.4.0
    unordered-containers-0.2.10.0-9ICZg3HcXJIzoexd54oj9
    vector-0.12.1.2-AUE2RejTPuTGt751uxPY7M

haddock-interfaces:
    /usr/share/doc/haskell-hjsonpointer/html/hjsonpointer.haddock

haddock-html:         /usr/share/doc/haskell-hjsonpointer/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
